SpinBox
==============================

.. currentmodule:: enaml.widgets.spin_box

.. autoclass:: SpinBox


Backends
--------

Qt
^^

.. inheritance-diagram::
    enaml.widgets.qt.qt_spin_box.QtSpinBox
    :parts: 1

.. autoclass:: enaml.widgets.qt.qt_spin_box.QtSpinBox

Wx
^^

.. inheritance-diagram::
    enaml.widgets.wx.wx_spin_box.WXSpinBox
    :parts: 1

.. autoclass:: enaml.widgets.wx.wx_spin_box.WXSpinBox
